# -*- coding: utf-8 -*-
"""
Created on Sun Oct 30 13:38:58 2022

@author: druth
"""

import numpy as np
import pandas as pd
import matplotlib.pyplot as plt
import scipy.interpolate

'''
Code to produce child bubble size distributions based on Ruth, Aiyer, Riviere,
Perrard, and Deike, "Experimental observations and modelling of sub-Hinze
bubble production by turbulent bubble break-up" (2022).
'''

# PATH TO THE FOLDER IN WHICH THE SUPPLEMENTARY MATERIAL FILES HAVE BEEN UNZIPPED
folder = r'C:\path\to\unzipped\files\\'

# import the gamma and <chi_cap> data shown in Figure 19 (b) and (c)
df = pd.read_csv(folder+r'gamma_and_avgchicap.csv',index_col='nondim_Delta')

# power-law exponent for small child bubble sizes
alpha = -7./6

def compute_sizedist(nondim_Delta,nondim_delta,nondim_delta_min=None):
    '''
    Return the dimensionless volumetric child size distribution for a parent 
    bubble with dimensionless volume nondim_Delta, evaluated at the
    dimensionless child bubble volumes nondim_delta.
    '''
    
    # the minimum child size considered defaults to the smallest size evaluated
    if nondim_delta_min is None:
        nondim_delta_min = nondim_delta[0]
    
    # make sure the value of Delta is within the range for which there is data
    assert nondim_Delta>=df.index[0] and nondim_Delta<=df.index[-1]
    
    # interpolate gamma and <chi_cap> at the given value of nondim_Delta
    gamma = scipy.interpolate.interp1d(df.index,df['gamma'].values)(nondim_Delta)
    avg_chi_cap = scipy.interpolate.interp1d(df.index,df['avg_chi_cap'].values)(nondim_Delta)
    
    # compute coefficients a and b given equations 5.5 and 5.6
    a = (1 - avg_chi_cap) * ((gamma+2)*nondim_Delta)/(nondim_Delta**(gamma+2) - nondim_delta_min**(gamma+2))
    b = avg_chi_cap * ((alpha+2)*nondim_Delta) / (nondim_Delta**(alpha+2) - nondim_delta_min**(alpha+2))
    
    # compute the inertial and capillary contributions to the child size distribution (the two terms in 5.4)
    inertial_mechanism = a * nondim_delta**gamma
    capillary_mechanism = b * nondim_delta**alpha
    
    # sum them using equation 5.4
    nondim_size_dist = inertial_mechanism + capillary_mechanism
    
    return nondim_size_dist

'''
Show the child size distributions for four parent bubble sizes
'''    

# define the parent bubble sizes for which to compute the distributions
nondim_Delta_vals = np.geomspace(0.1,100,4)

# compute and plot each
fig,ax = plt.subplots()
for nondim_Delta in nondim_Delta_vals:
    
    # define the child sizes at which to compute the distribution
    min_child_size = 0.001    
    nondim_delta_vals = np.geomspace(min_child_size,nondim_Delta,1001)        
    
    # compute and plot the child size distribution
    nondim_size_dist = compute_sizedist(nondim_Delta,nondim_delta_vals,nondim_delta_min=min_child_size)        
    ax.loglog(nondim_delta_vals,nondim_size_dist,label='{:3.3f}'.format(nondim_Delta))

ax.legend(title=r'$\tilde{\Delta}$')
ax.set_xlabel(r'$\tilde{\delta}$')
ax.set_ylabel(r'$\tilde{p} ( \tilde{\delta}; \tilde{\Delta})$')
fig.tight_layout()    